# Build configuration

# set to 1 to enable bootstrap
%define bootstrap 0

%define with_clang 1

%if ! 0%{?bootstrap}
%define build_docs 0
%else
%define build_docs 0
%endif
%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 3

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qttools-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqthelp       %mklibname qt%{qtmajor}help %{qtmajor}
%define libqthelp_d     %mklibname qt%{qtmajor}help -d

%define libqtdesigner   %mklibname qt%{qtmajor}designer %{qtmajor}
%define libqtdesigner_d %mklibname qt%{qtmajor}designer -d

%define libqtclucene    %mklibname qt%{qtmajor}clucene %{qtmajor}
%define libqtclucene_d  %mklibname qt%{qtmajor}clucene -d

Name:           qttools5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} GUI toolkit
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz
Source1:        mageia-assistant-qt5.desktop
Source2:        mageia-designer-qt5.desktop
Source3:        mageia-linguist-qt5.desktop
Source4:        mageia-qdbusviewer-qt5.desktop
BuildRequires:  qtbase5-devel
%if ! 0%{?bootstrap}
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5Help)
%endif
%if %with_clang
BuildRequires:  clang-devel
%endif
BuildRequires:  llvm-devel

BuildRequires:  desktop-file-utils
BuildRequires:  imagemagick
BuildRequires:  sed

%if ! 0%{?bootstrap}
Requires:       qttranslations5
%endif
Requires:       qttools5-assistant
Requires:       qttools5-qtpaths

Provides:       qt%{qtmajor}-qttools = %{version}-%{release}
Provides:       qt%{qtmajor}-linguist = %{version}-%{release}

# Link against libclang-cpp.so
# https://fedoraproject.org/wiki/Changes/Stop-Shipping-Individual-Component-Libraries-In-clang-lib-Package
Patch5:         0001-Link-against-libclang-cpp.so-instead-of-the-clang-co.patch

#Patch from Mageia

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qttools
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch101:       0001-Ensure-FileAttributeSetTable-is-filled-ordered-so-we.patch
Patch102:       0002-Drop-superfluous-network-dependency-from-assistant-h.patch
Patch103:       0003-qdoc-Ensure-the-generated-temporary-header-file-is-c.patch


%description
Qt%{qtmajor} GUI tools.

%files
%{_qt5_bindir}/lconvert*
%{_bindir}/lconvert*
%{_qt5_bindir}/linguist*
%{_bindir}/linguist*
%{_qt5_bindir}/lprodump*
%{_bindir}/lprodump*
%{_qt5_bindir}/lrelease*
%{_bindir}/lrelease*
%{_qt5_bindir}/lupdate*
%{_bindir}/lupdate*
%{_qt5_bindir}/pixeltool*
%{_bindir}/pixeltool*
%{_qt5_bindir}/qtdiag
%{_bindir}/qtdiag
%{_qt5_bindir}/qtplugininfo*
%{_bindir}/qtplugininfo*
%if ! 0%{?bootstrap}
%{_qt5_bindir}/qdistancefieldgenerator*
%{_bindir}/qdistancefieldgenerator*
%endif
%if %with_clang
%{_qt5_bindir}/qdoc
%{_bindir}/qdoc
%endif
%{_qt5_datadir}/phrasebooks
%{_bindir}/qtattributionsscanner-qt5
%{_qt5_bindir}/qtattributionsscanner*
%{_datadir}/applications/*linguist*.desktop
%{_iconsdir}/hicolor/*/apps/linguist-qt5.png
#FIXME: in the good package ?
%{_qt5_examplesdir}/linguist

#------------------------------------------------------------------------------

%package assistant
Summary:        Qt%{qtmajor} Assistant Doc Utility
Group:          Documentation
Requires:       qtbase5-database-plugin-sqlite
%if ! 0%{?bootstrap}
Requires:       qttranslations5
%endif
Provides:       qt%{qtmajor}-qttools-assistant = %{version}-%{release}

%description assistant
Qt%{qtmajor} Assistant provides a documentation Browser.

%files assistant
%{_qt5_bindir}/assistant*
%{_bindir}/assistant*
%{_qt5_bindir}/qcollectiongen*
%{_bindir}/qcollectiongen*
%{_qt5_bindir}/qhelpgen*
%{_bindir}/qhelpgen*
%{_datadir}/applications/*assistant*.desktop
%{_iconsdir}/hicolor/*/apps/assistant-qt5.png
#FIXME: in the good package ?
%{_qt5_examplesdir}/assistant

#------------------------------------------------------------------------------

%package designer
Summary:        %{name} Visual Design Tool
Group:          Development/KDE and Qt
Requires:       qttranslations5
Provides:       qt%{qtmajor}-qttools-designer = %{version}-%{release}

%description designer
The Qt Designer is a visual design tool that makes designing and
implementing user interfaces a lot easier.

%files designer
%{_qt5_bindir}/design*
%{_bindir}/design*
%{_qt5_plugindir}/designer/
%{_datadir}/applications/*designer*.desktop
%{_iconsdir}/hicolor/*/apps/designer-qt5.png

#------------------------------------------------------------------------------

%package qtdbus
Summary:        Qt%{qtmajor} Dbus Binary
Group:          Development/KDE and Qt
Requires:       qttools5-qtpaths
Provides:       qt%{qtmajor}-qttools-qtdbus = %{version}-%{release}
Provides:       qt%{qtmajor}-qttools-qdbusviewer = %{version}-%{release}
Provides:       qt%{qtmajor}-qdbusviewer = %{version}-%{release}

%description qtdbus
Qt%{qtmajor} Dbus Binary.

The QtDBus module is a Unix-only library that you can use to perform
Inter-Process Communication using the D-Bus protocol.

%files qtdbus
%{_bindir}/qdbus-qt5
%{_qt5_bindir}/qdbus
%{_qt5_bindir}/qdbus-qt5
%{_bindir}/qdbus
%{_qt5_bindir}/qdbusviewer*
%{_bindir}/qdbusviewer*
%{_datadir}/applications/*qdbusviewer*.desktop
%{_iconsdir}/hicolor/*/apps/qdbusviewer-qt5.png

#------------------------------------------------------------------------------

%package qtpaths
Summary:        Qt%{qtmajor} Paths Binary
Group:          Development/KDE and Qt
Provides:       qt%{qtmajor}-qttools-qtpaths = %{version}-%{release}

%description qtpaths
Qt%{qtmajor} Paths Binary.

%files qtpaths
%{_qt5_bindir}/qtpaths
%{_bindir}/qtpaths

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtTools%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  %{name}-assistant
Recommends:     %{name}-assistant

%description doc
Documentation for APIs and tools in QtTools%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtassistant.qch
%{_qt5_docdir}/qtassistant/
%{_qt5_docdir}/qtdesigner.qch
%{_qt5_docdir}/qtdesigner/
%if %with_clang
%{_qt5_docdir}/qdoc.qch
%{_qt5_docdir}/qdoc/
%endif
%{_qt5_docdir}/qthelp.qch
%{_qt5_docdir}/qthelp/
%{_qt5_docdir}/qtlinguist.qch
%{_qt5_docdir}/qtlinguist/
%{_qt5_docdir}/qtuitools.qch
%{_qt5_docdir}/qtuitools/
%if ! 0%{?bootstrap}
%{_qt5_docdir}/qtdistancefieldgenerator.qch
%{_qt5_docdir}/qtdistancefieldgenerator/
%endif

%endif

#------------------------------------------------------------------------------

%package -n %{libqthelp}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qthelplib = %{version}

%description -n %{libqthelp}
Qt%{qtmajor} Component Library.

The QtHelp module provides classes for integrating online documentation
in applications.

%files -n %{libqthelp}
%{_qt5_libdir}/libQt5Help.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqthelp_d}
Summary:        Devel files needed to build apps based on QtHelp and QtLinguistTools
Group:          Development/KDE and Qt
Requires:       %{libqthelp} = %{version}
Requires:       qtbase5-common-devel = %{version}
Requires:       qttools5
Provides:       libqthelp5-devel = %{version}
Provides:       libqt5help-devel = %{version}
Provides:       qthelp5-devel = %{version}
Provides:       qt5help-devel = %{version}
Provides:       qtlinguisttools5-devel = %{version}
Provides:       qt5linguisttools-devel = %{version}
Provides:       qtdoctools5-devel = %{version}
Provides:       qt5doctools-devel = %{version}

Provides:       libqthelp5-private-devel = %{version}
Provides:       libqt5help-private-devel = %{version}
Provides:       qthelp5-private-devel = %{version}
Provides:       qt5help-private-devel = %{version}

%description -n %{libqthelp_d}
Devel files needed to build apps based on QtHelp and QtLinguistTools.

%files -n %{libqthelp_d}
%{_qt5_libdir}/libQt5Help.prl
%{_qt5_libdir}/libQt5Help.so
%{_qt5_libdir}/pkgconfig/Qt5Help.pc
%{_qt5_includedir}/QtHelp/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_help.pri
%{_qt5_examplesdir}/help/
%dir %{_qt5_libdir}/cmake/Qt5Help
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfig.cmake
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfigVersion.cmake
%{_qt5_libdir}/cmake/Qt5Help/Qt5HelpConfigExtras.cmake
#FIXME: Find a better place
%dir %{_qt5_libdir}/cmake/Qt5LinguistTools
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsMacros.cmake
%{_qt5_libdir}/cmake/Qt5LinguistTools/Qt5LinguistToolsConfigVersion.cmake
%dir %{_qt5_libdir}/cmake/Qt5AttributionsScannerTools
%{_qt5_libdir}/cmake/Qt5AttributionsScannerTools/Qt5AttributionsScannerToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5AttributionsScannerTools/Qt5AttributionsScannerToolsConfigVersion.cmake
%if %with_clang
%dir %{_qt5_libdir}/cmake/Qt5DocTools
%{_qt5_libdir}/cmake/Qt5DocTools/Qt5DocToolsConfig.cmake
%{_qt5_libdir}/cmake/Qt5DocTools/Qt5DocToolsConfigVersion.cmake
%endif
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_help_private.pri

#------------------------------------------------------------------------------
%if 0
%package -n %{libqtclucene}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qtclucenelib = %{version}

%description -n %{libqtclucene}
Qt%{qtmajor} Component Library.

%files -n %{libqtclucene}
%{_qt5_libdir}/libQt5CLucene.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtclucene_d}
Summary:        Devel files needed to build apps based on QtCLucene
Group:          Development/KDE and Qt
Requires:       %{libqtclucene} = %{version}
Provides:       libqtclucene5-devel = %{version}
Provides:       libqt5clucene-devel = %{version}
Provides:       qtclucene5-devel = %{version}
Provides:       qt5clucene-devel = %{version}

Provides:       libqtclucene5-private-devel = %{version}
Provides:       libqt5clucene-private-devel = %{version}
Provides:       qtclucene5-private-devel = %{version}
Provides:       qt5clucene-private-devel = %{version}

%description -n %{libqtclucene_d}
Devel files needed to build apps based on QtCLucene.

%files -n %{libqtclucene_d}
%{_qt5_libdir}/libQt5CLucene.prl
%{_qt5_libdir}/libQt5CLucene.so
%{_qt5_includedir}/QtCLucene
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_clucene_private.pri
%endif

#------------------------------------------------------------------------------

%package -n %{libqtdesigner}
Summary:        Qt%{qtmajor} Component Library
Group:          System/Libraries
Provides:       qtdesignerlib = %{version}

%description -n %{libqtdesigner}
Qt%{qtmajor} Component Library.

The QtDesigner module provides classes that allow you to create your own
custom widget plugins for Qt Designer, and classes that enable you to
access Qt Designer's components.

%files -n %{libqtdesigner}
%{_qt5_libdir}/libQt5Designer.so.%{qtmajor}{,.*}
%{_qt5_libdir}/libQt5DesignerComponents.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtdesigner_d}
Summary:        Devel files needed to build apps based on QtDesigner
Group:          Development/KDE and Qt
Requires:       %{libqtdesigner} = %{version}
Requires:       qttools5-designer = %{version}
Provides:       libqtdesigner5-devel = %{version}
Provides:       libqt5designer-devel = %{version}
Provides:       qtdesigner5-devel = %{version}
Provides:       qt5designer-devel = %{version}

Provides:       libqtdesigner5-private-devel = %{version}
Provides:       libqt5designer-private-devel = %{version}
Provides:       qtdesigner5-private-devel = %{version}
Provides:       qt5designer-private-devel = %{version}

%description -n %{libqtdesigner_d}
Devel files needed to build apps based on QtDesigner.

%files -n %{libqtdesigner_d}
%{_qt5_libdir}/libQt5Designer.so
%{_qt5_libdir}/libQt5DesignerComponents.so
%{_qt5_libdir}/libQt5Designer.prl
%{_qt5_libdir}/libQt5DesignerComponents.prl
%{_qt5_libdir}/libQt5UiTools.prl
%{_qt5_libdir}/libQt5UiPlugin.prl
%{_qt5_libdir}/libQt5UiTools.a
%{_qt5_libdir}/pkgconfig/Qt5Designer.pc
%{_qt5_libdir}/pkgconfig/Qt5UiTools.pc
%{_qt5_libdir}/pkgconfig/Qt5UiPlugin.pc
%{_qt5_includedir}/QtDesignerComponents/
%{_qt5_includedir}/QtDesigner/
%{_qt5_includedir}/QtUiPlugin/
%{_qt5_includedir}/QtUiTools/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designer.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uitools.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uiplugin.pri
%{_qt5_examplesdir}/designer
%{_qt5_examplesdir}/uitools
%{_qt5_libdir}/cmake/Qt5Designer/
%{_qt5_libdir}/cmake/Qt5UiTools/
%{_qt5_libdir}/cmake/Qt5UiPlugin/
%{_qt5_libdir}/cmake/Qt5DesignerComponents/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designer_private.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_designercomponents_private.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_uitools_private.pri

#------------------------------------------------------------------------------

%prep
%autosetup -p1 -n qttools-everywhere-src-%{qtversion}

%build
%qmake_qt5

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# Add desktop files, icons...
desktop-file-install \
  --dir=%{buildroot}%{_datadir}/applications \
  %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4}
sed -i -e 's#/usr/lib/qt5/bin#%{_qt5_bindir}#' %{buildroot}%{_datadir}/applications/*.desktop
for i in 32 48 64 128; do
	mkdir -p %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
	convert -scale ${i}x${i} src/designer/src/designer/images/designer.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/designer-qt5.png
	convert -scale ${i}x${i} src/assistant/assistant/images/assistant-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/assistant-qt5.png
	convert -scale ${i}x${i} src/linguist/linguist/images/icons/linguist-128-32.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/linguist-qt5.png
	convert -scale ${i}x${i} src/qdbus/qdbusviewer/images/qdbusviewer-128.png %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/qdbusviewer-qt5.png
done

# hardlink files to {_bindir}, add -qt5 postfix to not conflict
mkdir %{buildroot}%{_bindir}
pushd %{buildroot}%{_qt5_bindir}
for i in * ; do
  case "${i}" in
   assistant|designer|lconvert|linguist|lrelease|lupdate|pixeltool|qcollectiongenerator|qdbus|qdbusviewer|qhelpconverter|qhelpgenerator|qtplugininfo|qtattributionsscanner)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}-qt5
      ln -sv ${i} ${i}-qt5
      ;;
    *)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}
      ;;
  esac
done
popd


# Fix all buildroot paths
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L%{_builddir}/\S+,,g" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} \;
find %{buildroot}%{_qt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L%{_builddir}/?\S+,,g" {} \;

# Don't reference builddir neither /usr(/X11R6)?/ in .pc files.
perl -pi -e '\
s@-L/usr/X11R6/%{_lib} @@g;\
s@-I/usr/X11R6/include @@g;\
s@-L/%{_builddir}\S+@@g'\
    `find . -name \*.pc`

mkdir -p %{buildroot}%{_bindir}

pushd %{buildroot}%{_bindir}
	for i in assistant designer lconvert linguist lrelease lupdate pixeltool qcollectiongenerator qdbus qdbusviewer qhelpgenerator qtplugininfo ; do 
				ln -s %{_qt5_bindir}/$i . ;
	done
popd


%changelog
* Fri May 02 2025 wally <wally> 5.15.16-3.mga10
+ Revision: 2180414
- non-bootstrap build without docs

* Thu May 01 2025 wally <wally> 5.15.16-2.mga10
+ Revision: 2180349
- enable bootstrap build
- rebuild for llvm 20.1.3

* Sun Jan 19 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139861
- non-bootstrap build

* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-0.1.mga10
+ Revision: 2139582
- New version 5.15.16

* Tue Nov 19 2024 daviddavid <daviddavid> 5.15.12-9.mga10
+ Revision: 2117732
- non bootstrap build

* Tue Nov 19 2024 daviddavid <daviddavid> 5.15.12-8.mga10
+ Revision: 2117700
- rebuild for llvm 19.1.3

* Sun Mar 31 2024 daviddavid <daviddavid> 5.15.12-7.mga10
+ Revision: 2053470
- non-boostrap build

* Sun Mar 31 2024 daviddavid <daviddavid> 5.15.12-6.mga10
+ Revision: 2053415
- bootstrap build
- rebuild for new llvm/clang 17

* Fri Feb 09 2024 daviddavid <daviddavid> 5.15.12-5.mga10
+ Revision: 2039835
- add virtual provides qt5-linguist (mga#32787)

* Fri Jan 19 2024 daviddavid <daviddavid> 5.15.12-4.mga10
+ Revision: 2032195
- add a desktop file for qdbusviewer tool
- improve desktop icons for assistant, designer and linguist tools

* Fri Jan 19 2024 daviddavid <daviddavid> 5.15.12-3.mga10
+ Revision: 2032179
- enable Qt Distance Field Generator tool

* Wed Jan 17 2024 daviddavid <daviddavid> 5.15.12-2.mga10
+ Revision: 2031836
- merge QT/KDE Collection Patches from kde/5.15 branch
- non-bootstrap build

* Tue Jan 16 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2031572
- New version 5.15.12

* Fri Dec 16 2022 daviddavid <daviddavid> 5.15.7-2.mga9
+ Revision: 1923526
- non bootstrap build to re-enable docs

* Mon Dec 05 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1917910
- New version 5.15.7

* Thu Sep 22 2022 neoclust <neoclust> 5.15.6-7.mga9
+ Revision: 1891717
- Disable bootstrap

* Thu Sep 22 2022 neoclust <neoclust> 5.15.6-6.mga9
+ Revision: 1891682
- Enable bootstrap agains
- Rebuild w/o bootstrap and with clang

* Thu Sep 22 2022 neoclust <neoclust> 5.15.6-5.mga9
+ Revision: 1891543
- Bootstrap + disable clang in order to fix armv7hl build
+ pterjan <pterjan>
- armv7hl is still built for llvm 13
+ tv <tv>
- Rebuild for llvm-15

* Mon Sep 19 2022 neoclust <neoclust> 5.15.6-2.mga9
+ Revision: 1890339
- Disable bootstrap build

* Thu Sep 08 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886035
- Enable bootstrap
- New version 5.15.6

* Fri Aug 26 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1880572
+ rebuild (emptylog)

* Tue Aug 23 2022 wally <wally> 5.15.2-11.mga9
+ Revision: 1879746
- disable bootstrap build to get Qml support to lupdate

* Sat Apr 02 2022 tv <tv> 5.15.2-10.mga9
+ Revision: 1840360
- Rebuild for llvm-14

* Sat Mar 26 2022 umeabot <umeabot> 5.15.2-9.mga9
+ Revision: 1828151
- Mageia 9 Mass Rebuild

* Thu Oct 21 2021 tv <tv> 5.15.2-8.mga9
+ Revision: 1752511
- Rebuild for llvm 13.0

* Thu Oct 21 2021 neoclust <neoclust> 5.15.2-7.mga9
+ Revision: 1752468
- Rebuild against new llvm

* Tue Oct 19 2021 neoclust <neoclust> 5.15.2-6.mga9
+ Revision: 1752085
- Add Patches from KDE Qt Collection

* Wed Mar 03 2021 daviddavid <daviddavid> 5.15.2-5.mga9
+ Revision: 1697356
- do a non bootstrap build

* Tue Mar 02 2021 neoclust <neoclust> 5.15.2-4.mga9
+ Revision: 1696064
- Enable clang
- Disable bootstrap mode

* Tue Mar 02 2021 neoclust <neoclust> 5.15.2-3.mga9
+ Revision: 1695985
- Enable bootstrap
- Add a switch to allow to build w/o clang
+ tv <tv>
- rebuild for llvm/clang-12

* Sat Dec 05 2020 daviddavid <daviddavid> 5.15.2-2.mga8
+ Revision: 1652823
- non bootstrap build

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652491
- New version 5.15.2

* Thu Nov 26 2020 tmb <tmb> 5.15.1-4.mga8
+ Revision: 1649588
- rebuild for clang/llvm 11

* Wed Oct 21 2020 akien <akien> 5.15.1-3.mga8
+ Revision: 1637692
- Rebuild for fixed qtgui5 with vulkan dependency

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-2.mga8
+ Revision: 1625220
- non-bootstrap build

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624940
- New version 5.15.1

* Sun Jun 28 2020 daviddavid <daviddavid> 5.15.0-2.mga8
+ Revision: 1599881
- non bootstrap build

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589812
- New version 5.15.0

* Tue Apr 28 2020 daviddavid <daviddavid> 5.14.1-4.mga8
+ Revision: 1572947
- split out in a separate package qtpaths binary
- improve some descriptions and summaries
+ danf <danf>
- Switch URLs from http: to https:

* Sun Mar 22 2020 tv <tv> 5.14.1-3.mga8
+ Revision: 1558787
- rebuild with llvm 10

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545300
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484460
- New version 5.14.1

* Tue Sep 17 2019 tv <tv> 5.13.1-3.mga8
+ Revision: 1443070
- rebuild for llvm-9.0
- rebuild for llvm-9.0
+ neoclust <neoclust>
- New version 5.13.1

* Sun Sep 08 2019 daviddavid <daviddavid> 5.13.1-2.mga8
+ Revision: 1438414
- rebuild for arm

* Sat Sep 07 2019 daviddavid <daviddavid> 5.13.1-1.mga8
+ Revision: 1438057
- New version 5.13.1

* Wed Jul 24 2019 wally <wally> 5.13.0-3.mga8
+ Revision: 1423727
- rebuild with fixed qtbase5

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421091
- Rebuild against qt new locations

* Wed Jul 03 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1417951
- New version 5.13.0

* Mon Apr 15 2019 tmb <tmb> 5.12.2-3.mga7
+ Revision: 1390730
- rebuild for new llvm/clang

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384574
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378550
- New version 5.12.0

* Sat Feb 02 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362360
- New version 5.12.1

* Fri Dec 14 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1341258
- New version 5.12.0

* Fri Nov 23 2018 tv <tv> 5.11.2-2.mga7
+ Revision: 1333461
- hardlink files to /bin, add -qt5 postfix like FC (needed by vbox)

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319039
- New version 5.11.2

* Thu Sep 27 2018 tv <tv> 5.11.1-3.mga7
+ Revision: 1308217
- bootstrap for llvm/clang 7.0
- rebuild for llvm/clang 7.0
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245825
- New version 5.11.1

* Mon May 28 2018 daviddavid <daviddavid> 5.11.0-5.mga7
+ Revision: 1232748
- non bootstrap build
- fix non-existent Qt5UiPlugin.pc

* Sun May 27 2018 neoclust <neoclust> 5.11.0-4.mga7
+ Revision: 1232566
- Add back qdoc in file list
- Fix BR deps logic

* Sun May 27 2018 neoclust <neoclust> 5.11.0-2.mga7
+ Revision: 1232561
- Add more builddeps to fix qdoc build

* Sun May 27 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232556
- Enable bootstrap
- New version 5.11.0

* Mon Apr 09 2018 neoclust <neoclust> 5.10.1-1.mga7
+ Revision: 1216519
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205687
- New version 5.9.4

* Mon Dec 18 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1183197
- New version 5.9.3

* Sat Aug 05 2017 daviddavid <daviddavid> 5.9.1-3.mga7
+ Revision: 1135075
- do a non bootstrap build

* Wed Jul 19 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1124932
- New version 5.9.1

* Sun Mar 12 2017 neoclust <neoclust> 5.6.2-4.mga6
+ Revision: 1092255
- Qtlinguist need qtassistant (mga#20416)

* Sat Dec 31 2016 neoclust <neoclust> 5.6.2-3.mga6
+ Revision: 1078779
- Put binaries in bindir ( symlinks )

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-2.mga6
+ Revision: 1065056
- Rebuild against qtbase 5.6.2

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-1.mga6
+ Revision: 1064831
- New version 5.6.2

* Fri Sep 02 2016 daviddavid <daviddavid> 5.6.1-4.mga6
+ Revision: 1049774
- recommends qttools5-assistant instead

* Wed Aug 31 2016 daviddavid <daviddavid> 5.6.1-3.mga6
+ Revision: 1049623
- build missing docs part (mga#9812)
- add qttools5-doc subpackage

* Sun Jul 03 2016 neoclust <neoclust> 5.6.1-2.mga6
+ Revision: 1038383
- Update to version 5.6.1-1
- New version

* Wed May 11 2016 akien <akien> 5.6.0-2.mga6
+ Revision: 1013637
- Fix libname s/libqthelp5/libqt5help5/ etc.

* Thu Mar 17 2016 neoclust <neoclust> 5.6.0-1.mga6
+ Revision: 992504
+ rebuild (emptylog)

* Wed Mar 09 2016 neoclust <neoclust> 5.6.0-0.rc.2.mga6
+ Revision: 987913
- Rebuild Qt5 Stack to fix plasma crashes

* Sun Feb 28 2016 neoclust <neoclust> 5.6.0-0.rc.1.mga6
+ Revision: 980619
+ rebuild (emptylog)

* Tue Feb 16 2016 umeabot <umeabot> 5.6.0-0.beta.5.mga6
+ Revision: 962557
- Mageia 6 Mass Rebuild
+ neoclust <neoclust>
- Rebuild against new cmake to have cmake() provides

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.3.mga6
+ Revision: 915770
- Rebuild against new cmake to have cmake() provides

* Mon Dec 21 2015 neoclust <neoclust> 5.6.0-0.beta.2.mga6
+ Revision: 912763
- Remove private devel packages

* Sat Dec 19 2015 neoclust <neoclust> 5.6.0-0.beta.1.mga6
+ Revision: 912086
- New version 5.6.0 Beta

* Tue Nov 10 2015 neoclust <neoclust> 5.5.1-2.mga6
+ Revision: 900345
- Rebuild against fixed qtbase5

* Fri Oct 23 2015 neoclust <neoclust> 5.5.1-1.mga6
+ Revision: 894504
- New version
+ alexl <alexl>
- delete Encoding, add GenericName for desktop files

* Sun Jul 12 2015 filipesaraiva <filipesaraiva> 5.5.0-1.mga6
+ Revision: 853388
- Update to Qt 5.5.0 version;
- Fix URL to new address qt.io;
- Delete old sources;

* Wed Jun 24 2015 neoclust <neoclust> 5.5.0-0.rc.1.mga6
+ Revision: 841765
- New version 5.5 rc

* Thu Dec 18 2014 neoclust <neoclust> 5.4.0-2.mga5
+ Revision: 804025
- Fix Requires on qttools-designer

* Sat Dec 13 2014 neoclust <neoclust> 5.4.0-1.mga5
+ Revision: 802883
- New version 5.4.0

* Sun Dec 07 2014 neoclust <neoclust> 5.3.2-1.mga5
+ Revision: 802090
- New version 5.3.2

* Wed Oct 15 2014 umeabot <umeabot> 5.3.1-5.mga5
+ Revision: 751152
- Second Mageia 5 Mass Rebuild

* Sun Oct 12 2014 umeabot <umeabot> 5.3.1-4.mga5
+ Revision: 738099
- Mageia 5 Mass Rebuild

* Thu Jul 24 2014 neoclust <neoclust> 5.3.1-3.mga5
+ Revision: 656183
- Add BR to add qml support for lupdate ( mga #13781 )
- Add BR to add qml support for lupdate ( mga #13781 )

* Sun Jul 06 2014 neoclust <neoclust> 5.3.1-2.mga5
+ Revision: 644217
- Fix require for  qttools5 in qt5help-devel

* Thu Jun 26 2014 fwang <fwang> 5.3.1-1.mga5
+ Revision: 639875
- update file list
- 5.3.1

* Tue May 20 2014 fwang <fwang> 5.3.0-1.mga5
+ Revision: 624063
- 5.3.0 final

* Fri May 09 2014 fwang <fwang> 5.3.0-0.rc.1.mga5
+ Revision: 621458
- 5.3.0 rc

* Sun Apr 06 2014 fwang <fwang> 5.3.0-0.beta.1.mga5
+ Revision: 612345
- update file list
- 5.3.0beta

* Mon Mar 03 2014 neoclust <neoclust> 5.3.0-0.alpha.1.mga5
+ Revision: 598949
- New version 5.3.0 Alpha1

* Thu Feb 06 2014 fwang <fwang> 5.2.1-1.mga5
+ Revision: 584204
- 5.2.1
- 5.2.1

* Mon Dec 23 2013 neoclust <neoclust> 5.2.0-3.mga4
+ Revision: 560259
- Add qt5webkitwidgets-devel as Buildrequire mga #11998

* Sat Dec 14 2013 fwang <fwang> 5.2.0-2.mga4
+ Revision: 556704
- 5.2.0 final

* Sun Dec 01 2013 fwang <fwang> 5.2.0-1.rc1.1.mga4
+ Revision: 554418
- update file list
- update file list
- update file list
- 5.2.0 rc1

* Sat Oct 26 2013 fwang <fwang> 5.2.0-1.beta1.1.mga4
+ Revision: 547070
- 5.2.0 beta1

* Mon Oct 21 2013 umeabot <umeabot> 5.2.0-1.alpha.2.mga4
+ Revision: 538877
- Mageia 4 Mass Rebuild

* Thu Oct 03 2013 fwang <fwang> 5.2.0-1.alpha.1.mga4
+ Revision: 490719
- update file list
- 5.2.0 alpha1

* Sat Aug 10 2013 wally <wally> 5.2.0-0.0.20130523.4.mga4
+ Revision: 465116
- fix typo in cmake path patch

* Sat Aug 10 2013 wally <wally> 5.2.0-0.0.20130523.3.mga4
+ Revision: 465096
- add patch to fix cmake paths

* Mon May 27 2013 neoclust <neoclust> 5.2.0-0.0.20130523.2.mga4
+ Revision: 428825
- Rebuild against new qt5 libs location

* Sun May 26 2013 neoclust <neoclust> 5.2.0-0.0.20130523.1.mga4
+ Revision: 428071
- New QT 5.2 Snapshot
- New QT 5.2 Snapshot

* Wed Apr 17 2013 neoclust <neoclust> 5.0.2-1.mga3
+ Revision: 410386
- New version 5.0.2

* Sat Feb 02 2013 fwang <fwang> 5.0.1-2.mga3
+ Revision: 394054
- fix exec path of desktop file

* Sat Feb 02 2013 neoclust <neoclust> 5.0.1-1.mga3
+ Revision: 393995
- New version 5.0.1 Final

* Thu Jan 31 2013 neoclust <neoclust> 5.0.1-0.rc1.3.mga3
+ Revision: 393622
- Fix files lists
- Move private header in their own package

* Sat Jan 26 2013 neoclust <neoclust> 5.0.1-0.rc1.2.mga3
+ Revision: 392575
- Add back .a files, needed by a qt5 package

* Sat Jan 26 2013 neoclust <neoclust> 5.0.1-0.rc1.1.mga3
+ Revision: 392376
- New version 5.0.1 rc1
+ fwang <fwang>
- use xz

* Wed Jan 23 2013 neoclust <neoclust> 5.0.0-1.mga3
+ Revision: 391506
- Qt 5.0.0 FINAL
- New version rc1
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 17 2012 neoclust <neoclust> 5.0.0-0.beta.17.mga3
+ Revision: 319084
- Fix wrong requires

* Fri Nov 16 2012 neoclust <neoclust> 5.0.0-0.beta.16.mga3
+ Revision: 318480
- imported package qttools5

